==> nextcloud-15.0.7.zip: nextcloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "空間暫時無法使用",
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "All files" : "所有檔案",
    "Recent" : "近期",
    "Favorites" : "最愛",
    "File could not be found" : "找不到檔案",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "刪除",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "This will stop your current uploads." : "這會終止目前任何的上傳。",
    "Upload cancelled." : "上傳已取消",
    "Processing files …" : "正在處理檔案…",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
    "Not enough free space" : "空間不足",
    "An unknown error has occurred" : "發生未知的錯誤",
    "Uploading …" : "上傳中...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "不支援上傳該項目",
    "Target folder does not exist any more" : "目標資料夾已經不存在了",
    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
    "Actions" : "動作",
    "Rename" : "重新命名",
    "Copy" : "複製",
    "Choose target folder" : "選擇目標資料夾",
    "Open" : "開啟",
    "Disconnect storage" : "切斷儲存空間連接",
    "Unshare" : "取消分享",
    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
    "Files" : "檔案",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "copy" : "複製",
    "Could not copy \"{file}\", target exists" : "無法複製\"{file}\"，目標已存在",
    "Could not copy \"{file}\"" : "無法複製\"{file}\"",
    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隱藏檔"],
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "Select file range" : "選擇多個檔案",
    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
    "{used} used" : "已使用 {used}",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "View in folder" : "在資料夾中檢視",
    "Copied!" : "已複製",
    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結(只對能存取的用戶有用)",
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
    "New folder" : "新資料夾",
    "Upload file" : "上傳檔案",
    "Not favorited" : "未加入至最愛",
    "Remove from favorites" : "從最愛中移除",
    "Add to favorites" : "添加到最愛",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "Added to favorites" : "已添加到最愛",
    "Removed from favorites" : "已從最愛中移除",
    "You added {file} to your favorites" : "你已添加 {file} 至最愛",
    "You removed {file} from your favorites" : "你已移除 {file} 從最愛",
    "File changes" : "檔案更動",
    "Created by {user}" : "由 {user} 建立",
    "Changed by {user}" : "由 {user} 改動",
    "Deleted by {user}" : "由 {user} 刪除",
    "Restored by {user}" : "由 {user} 還原",
    "Renamed by {user}" : "由 {user} 重新命名",
    "Moved by {user}" : "由 {user} 移動",
    "\"remote user\"" : "「遠端用戶」",
    "You created {file}" : "您建立了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 建立了一個加密的檔案",
    "{user} created {file}" : "{user} 建立了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 建立了一個加密的檔案",
    "{file} was created in a public folder" : "{file} 已建立於共享資料夾",
    "You changed {file}" : "您變更了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 修改了一個加密的檔案",
    "{user} changed {file}" : "{user} 變更了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 修改了一個加密的檔案",
    "You deleted {file}" : "您刪除了 {file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 刪除了一個加密的檔案",
    "{user} deleted {file}" : "{user} 刪除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 刪除了一個加密的檔案",
    "You restored {file}" : "您還原了 {file}",
    "{user} restored {file}" : "{user} 還原了 {file}",
    "You renamed {oldfile} to {newfile}" : "您變更 {oldfile} 為 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 變更 {oldfile} 為 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移動 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移動 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "檔案已被新增或移除從 <strong>最愛</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "檔案或目錄已被 <strong>更動</strong> 或 <strong>改名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "Unlimited" : "無限制",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "File Management" : "檔案管理",
    "%s of %s used" : "在 %s 中使用了%s ",
    "%1$s%% of %2$s used" : "在%2$s使用了%1$s%%",
    "%s used" : "%s已使用",
    "Settings" : "設定",
    "Show hidden files" : "顯示隱藏檔",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
    "Toggle grid view" : "切換網格檢視",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites yet" : "尚無最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Tags" : "標籤",
    "Deleted files" : "回收桶",
    "Shares" : "分享",
    "Shared with others" : "與其他人分享",
    "Shared with you" : "與您分享",
    "Shared by link" : "由連結分享",
    "Deleted shares" : "已刪除的分享",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt",
    "Target folder" : "目標資料夾",
    "File handling" : "檔案處理",
    "Maximum upload size" : "上傳限制",
    "max. possible: " : "最大允許：",
    "Save" : "儲存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
    "Cancel upload" : "取消上傳",
    "%1$s of %2$s used" : "在  %2$s中使用了%1$s "
},
"nplurals=1; plural=0;");

==> nextcloud-17.0.6.zip: nextcloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "空間暫時無法使用",
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "All files" : "所有檔案",
    "Recent" : "近期",
    "Favorites" : "最愛",
    "File could not be found" : "找不到檔案",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "刪除",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "This will stop your current uploads." : "這會終止目前任何的上傳。",
    "Upload cancelled." : "上傳已取消",
    "Processing files …" : "正在處理檔案…",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
    "Not enough free space" : "空間不足",
    "An unknown error has occurred" : "發生未知的錯誤",
    "Uploading …" : "上傳中...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "不支援上傳該項目",
    "Target folder does not exist any more" : "目標資料夾已經不存在了",
    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
    "Actions" : "動作",
    "Rename" : "重新命名",
    "Copy" : "複製",
    "Choose target folder" : "選擇目標資料夾",
    "Open" : "開啟",
    "Delete file" : "刪除檔案",
    "Delete folder" : "刪除資料夾",
    "Disconnect storage" : "切斷儲存空間連接",
    "Unshare" : "取消分享",
    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
    "Files" : "檔案",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "copy" : "複製",
    "Could not copy \"{file}\", target exists" : "無法複製\"{file}\"，目標已存在",
    "Could not copy \"{file}\"" : "無法複製\"{file}\"",
    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Could not fetch file details \"{file}\"" : "不能取得檔案細節\"{file}\"",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隱藏檔"],
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "Select file range" : "選擇多個檔案",
    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
    "{used} used" : "已使用 {used}",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "View in folder" : "在資料夾中檢視",
    "Copied!" : "已複製",
    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結(只對能存取的用戶有用)",
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "You can only favorite a single file or folder at a time" : "您一次只能為一個檔案或資料夾加星號",
    "New folder" : "新資料夾",
    "Upload file" : "上傳檔案",
    "Not favorited" : "未加入至最愛",
    "Remove from favorites" : "從最愛中移除",
    "Add to favorites" : "添加到最愛",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "Added to favorites" : "已添加到最愛",
    "Removed from favorites" : "已從最愛中移除",
    "You added {file} to your favorites" : "你已添加 {file} 至最愛",
    "You removed {file} from your favorites" : "你已移除 {file} 從最愛",
    "File changes" : "檔案更動",
    "Created by {user}" : "由 {user} 建立",
    "Changed by {user}" : "由 {user} 改動",
    "Deleted by {user}" : "由 {user} 刪除",
    "Restored by {user}" : "由 {user} 還原",
    "Renamed by {user}" : "由 {user} 重新命名",
    "Moved by {user}" : "由 {user} 移動",
    "\"remote user\"" : "「遠端用戶」",
    "You created {file}" : "您建立了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 建立了一個加密的檔案",
    "{user} created {file}" : "{user} 建立了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 建立了一個加密的檔案",
    "{file} was created in a public folder" : "{file} 已建立於共享資料夾",
    "You changed {file}" : "您變更了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 修改了一個加密的檔案",
    "{user} changed {file}" : "{user} 變更了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 修改了一個加密的檔案",
    "You deleted {file}" : "您刪除了 {file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 刪除了一個加密的檔案",
    "{user} deleted {file}" : "{user} 刪除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 刪除了一個加密的檔案",
    "You restored {file}" : "您還原了 {file}",
    "{user} restored {file}" : "{user} 還原了 {file}",
    "You renamed {oldfile} to {newfile}" : "您變更 {oldfile} 為 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 變更 {oldfile} 為 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移動 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移動 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "檔案已被新增或移除從 <strong>最愛</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "檔案或目錄已被 <strong>更動</strong> 或 <strong>改名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "Unlimited" : "無限制",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "Incoming ownership transfer from {user}" : "來自 {user} 的所有權轉移",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您想要接收 \"{path}\" 嗎？\n\n註：所有權轉移的流程最多需要一小時",
    "Ownership transfer failed" : "所有權轉移失敗",
    "Your ownership transfer of {path} to {user} failed." : "您將 \"{path}\" 的所有權轉移給 {user} 失敗",
    "The ownership transfer of {path} from {user} failed." : "來自 {user} 的 \"{path}\" 所有權轉移失敗",
    "Ownership transfer done" : "所有權轉移完成",
    "Your ownership transfer of {path} to {user} has completed." : "您將 \"{path}\" 的所有權轉移給 {user} 已經完成",
    "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
    "File Management" : "檔案管理",
    "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
    "Change" : "更改",
    "New owner" : "新的擁有者",
    "Search users" : "搜尋使用者",
    "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
    "Transfer" : "轉移",
    "Transfer {path} to {userid}" : "轉移 \"{path}\" 給 {userid}",
    "Invalid path selected" : "所選的路徑無效",
    "Ownership transfer request sent" : "已送出所有權轉移的請求",
    "Tags" : "標籤",
    "Error while loading the file data" : "載入檔案資料失敗",
    "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
    "%s used" : "%s已使用",
    "%s%% of %s used" : "%s 在 %s 中使用了 %%",
    "%1$s of %2$s used" : "在  %2$s中使用了%1$s ",
    "Settings" : "設定",
    "Show hidden files" : "顯示隱藏檔",
    "WebDAV" : "WebDAV",
    "Toggle grid view" : "切換網格檢視",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites yet" : "尚無最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Deleted files" : "回收桶",
    "Shares" : "分享",
    "Shared with others" : "與其他人分享",
    "Shared with you" : "與您分享",
    "Shared by link" : "由連結分享",
    "Deleted shares" : "已刪除的分享",
    "Pending shares" : "等待分享",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt",
    "%s of %s used" : "在 %s 中使用了%s ",
    "%1$s%% of %2$s used" : "在%2$s使用了%1$s%%",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "無法轉換非您擁有檔案或資料夾的所有權"
},
"nplurals=1; plural=0;");
